@@ -198,7 +198,7 @@ int main (int argc, char *argv[])
 
 	gtk_signal_connect_after(GTK_OBJECT(menu_tree_ctree),
 				 "button_release_event",
-				 GTK_SIGNAL_FUNC(tree_item_selected),NULL);
+				 GTK_SIGNAL_FUNC(tree_item_selected), NULL);
 
 	gtk_signal_connect_after(GTK_OBJECT(menu_tree_ctree),
 				 "tree_collapse",
@@ -244,6 +244,14 @@ int main (int argc, char *argv[])
 
 	add_main_tree_node();
 
+	/*
+	 * We don't connect this until here so that we don't get signals
+	 * while the tree is being setup.
+	 */
+	gtk_signal_connect_after(GTK_OBJECT(menu_tree_ctree),
+				 "tree_select_row",
+				 GTK_SIGNAL_FUNC(tree_row_selected), NULL);
+
 	gtk_widget_show(app);
 	
 	new_edit_area();
@@ -288,7 +296,7 @@ static void sort_recursive_pressed(GtkWidget *w, gpointer data)
 static void about_cb(GtkWidget *w, gpointer data)
 {
 	GtkWidget *about;
-	const gchar *authors[2];
+	const gchar *authors[3];
 	gchar version[32];
 
 	sprintf(version,"%d.%d.%d",GMENU_VERSION_MAJOR, GMENU_VERSION_MINOR, GMENU_VERSION_REV);
@@ -298,7 +306,7 @@ static void about_cb(GtkWidget *w, gpointer data)
 	authors[2] = NULL;
 
 	about = gnome_about_new ( _("GNOME menu editor"), version,
-			"(C) 1998,1999",
+			"(C) 1999",
 			authors,
 			_("Released under the terms of the GNU Public License.\n"
 			"GNOME menu editor."),
