@@ -321,8 +321,7 @@ set_color_scheme (ZvtTerm *term, struct terminal_config *color_cfg)
 	zvt_term_set_color_scheme (term, red, green, blue);
 	c.pixel = term->colors [17];
 
-	gdk_window_set_background (GTK_WIDGET (term)->parent->window, &c);
-				   
+	gdk_window_set_background (GTK_WIDGET (term)->window, &c);
 	gtk_widget_queue_draw (GTK_WIDGET (term));
 }
 
@@ -596,30 +595,25 @@ switch_terminal_class (ZvtTerm *term, struct terminal_config *newcfg)
 			   term);
 
 	gtk_widget_show (mbox);
-
 }
 
 static void
-window_closed (GtkWidget *w, void *data)
+window_destroy (GtkWidget *w, gpointer data)
 {
 	ZvtTerm *term = ZVT_TERM (data);
 	preferences_t *prefs;
 
 	prefs = gtk_object_get_data (GTK_OBJECT (term), "prefs");
-	gtk_signal_disconnect_by_data(GTK_OBJECT(prefs->pixmap_file_entry),
-				      prefs);
+	gtk_signal_disconnect_by_data (GTK_OBJECT (prefs->pixmap_file_entry), prefs);
 	g_free (prefs);
-	
 	gtk_object_set_data (GTK_OBJECT (term), "prefs", NULL);
 }
 
 static int
-window_closed_event (GtkWidget *w, GdkEvent *event, void *data)
+window_delete_event (GtkWidget *w, GdkEvent *event, gpointer data)
 {
-	ZvtTerm *term = ZVT_TERM (data);
-	
-	window_closed (w, term);
-	return FALSE;
+	gtk_widget_destroy (w);
+	return TRUE;
 }
 
 /*
@@ -860,9 +854,15 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 	struct terminal_config *cfg;
 
 	/* Is a property window for this terminal already running? */
-	if (gtk_object_get_data (GTK_OBJECT (term), "prefs") ||
-	    gtk_object_get_data (GTK_OBJECT (term), "newcfg"))
+	if (gtk_object_get_data (GTK_OBJECT (term), "newcfg"))
 		return;
+	
+	prefs = gtk_object_get_data (GTK_OBJECT (term), "prefs");
+	if (prefs) {
+		/* Raise and possibly uniconify the property box */
+		gdk_window_show (prefs->prop_win->window);
+		return;
+	}
 
 	cfg = gtk_object_get_data (GTK_OBJECT (term), "config");
 
@@ -1117,9 +1117,9 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 	gtk_signal_connect (GTK_OBJECT (prefs->prop_win), "apply",
 			    GTK_SIGNAL_FUNC (apply_changes_cmd), term);
 	gtk_signal_connect (GTK_OBJECT (prefs->prop_win), "delete_event",
-			    GTK_SIGNAL_FUNC (window_closed_event), term);
+			    GTK_SIGNAL_FUNC (window_delete_event), term);
 	gtk_signal_connect (GTK_OBJECT (prefs->prop_win), "destroy",
-			    GTK_SIGNAL_FUNC (window_closed), term);
+			    GTK_SIGNAL_FUNC (window_destroy), term);
 
 	help_entry.name = gnome_app_id;
 	gtk_signal_connect (GTK_OBJECT (prefs->prop_win), "help",
@@ -1337,6 +1337,7 @@ drag_data_received  (GtkWidget *widget, GdkDragContext *context,
 			cfg->user_fore.blue  = data [2];
 		}
 		set_color_scheme (term, cfg);
+		save_preferences_cmd (widget, term);
 	}
 	}
 }
@@ -1388,11 +1389,18 @@ button_press (GtkWidget *widget, GdkEventButton *event, ZvtTerm *term)
 {
 	GtkWidget *menu;
 	struct terminal_config *cfg;
-
+	int popup = 0;
+	
 	cfg = gtk_object_get_data (GTK_OBJECT (term), "config");
 
-	/* FIXME: this should popup a menu instead */
-	if (event->state & GDK_CONTROL_MASK && event->button == 3){
+	if (event->button == 3){
+		if (event->state & GDK_CONTROL_MASK)
+			popup = 1;
+		else if (!(term->vx->vt.mode & VTMODE_SEND_MOUSE))
+			popup = 1;
+	}
+	
+	if (popup){
 		GnomeUIInfo *uiinfo;
 		GnomeUIBuilderData uib;
 		menu = gtk_menu_new (); 
@@ -1537,12 +1545,7 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 	terminals = g_list_append (terminals, app);
 
 	/* Setup the Zvt widget */
-	term = ZVT_TERM (zvt_term_new ());
-
-	/* set a default grid size for the terminal -- this
-	 * might be reset by the geometry option
-	 */
-	zvt_term_set_size (ZVT_TERM (term), 80, 25);
+	term = ZVT_TERM (zvt_term_new_with_size (80, 25));
 
 	if ((zvt_term_get_capabilities (term) & ZVT_TERM_PIXMAP_SUPPORT) != 0){
 		zvt_pixmap_support = TRUE;
@@ -1559,7 +1562,8 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 	zvt_term_set_blink (term, cfg->blink);
 	zvt_term_set_scroll_on_keystroke (term, cfg->scroll_key);
 	zvt_term_set_scroll_on_output (term, cfg->scroll_out);
-
+	zvt_term_set_del_key_swap (term, cfg->swap_keys);
+		
 	gtk_signal_connect (GTK_OBJECT (term), "child_died",
 			    GTK_SIGNAL_FUNC (terminal_kill), term);
 
@@ -1581,8 +1585,10 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 	
 	/* Decorations */
 	hbox = gtk_hbox_new (0, 0);
+
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 2);
 	gtk_box_set_spacing (GTK_BOX (hbox), 3);
+
 	gtk_widget_show (hbox);
 	get_shell_name (&shell, &name, cfg->invoke_as_login_shell);
 
