@@ -21,9 +21,10 @@ typedef struct _BasePWidgetClass	BasePWidgetClass;
 struct _BasePWidget
 {
 	GtkWindow		window;
+	GtkWidget		*ebox;
 	
 	GtkWidget		*panel;
-
+	
 	GtkWidget		*table;
 	GtkWidget		*hidebutton_n;
 	GtkWidget		*hidebutton_e;
@@ -32,6 +33,8 @@ struct _BasePWidget
 	
 	GtkWidget		*frame;
 
+	GtkAllocation		shown_alloc;
+
 	int			hidebuttons_enabled;
 	int			hidebutton_pixmaps_enabled;
 };
@@ -71,6 +74,21 @@ void		basep_widget_disable_buttons	(BasePWidget *basep);
 
 void		basep_widget_set_hidebuttons	(BasePWidget *basep);
 
+void		basep_widget_do_hiding		(BasePWidget *basep,
+						 PanelOrientType hide_orient,
+						 int leftover,
+						 int step);
+void		basep_widget_do_showing		(BasePWidget *basep,
+						 PanelOrientType hide_orient,
+						 int leftover,
+						 int step);
+void		basep_widget_get_position	(BasePWidget *basep,
+						 PanelOrientType hide_orient,
+						 int *x,
+						 int *y,
+						 int w,
+						 int h);
+
 END_GNOME_DECLS
 
 #endif /* __BASEP_WIDGET_H__ */
