@@ -106,7 +106,7 @@ drawer_widget_realize(GtkWidget *w)
 		gnome_win_hints_set_state(w,
 					  WIN_STATE_STICKY |
 					  WIN_STATE_FIXED_POSITION);
-		gnome_win_hints_set_layer(w, WIN_LAYER_DOCK);
+		gnome_win_hints_set_layer(w, WIN_LAYER_ABOVE_DOCK);
 		gnome_win_hints_set_expanded_size(w, 0, 0, 0, 0);
 		gdk_window_set_decorations(w->window, 0);
 	}
@@ -143,9 +143,6 @@ drawer_widget_class_init (DrawerWidgetClass *class)
 	widget_class->realize = drawer_widget_realize;
 }
 
-/*if this is set, the size request and size alloc calls are ignored*/
-static int ignore_allocate = FALSE;
-
 /*if this is true the size request will request a 48x48 cube, this is used
   during orientation changes to make no flicker*/
 static int drawer_widget_request_cube = FALSE;
@@ -156,8 +153,6 @@ drawer_widget_size_request(GtkWidget *widget,
 	DrawerWidget *drawer = DRAWER_WIDGET(widget);
 	BasePWidget *basep = BASEP_WIDGET(widget);
 	int w,h;
-	if(ignore_allocate)
-		return;
 	if(drawer_widget_request_cube) {
 		requisition->width = 48;
 		requisition->height = 48;
@@ -165,10 +160,10 @@ drawer_widget_size_request(GtkWidget *widget,
 		return;
 	}
 
-	gtk_widget_size_request (basep->table, &basep->table->requisition);
+	gtk_widget_size_request (basep->ebox, &basep->ebox->requisition);
 
-	w = basep->table->requisition.width;
-	h = basep->table->requisition.height;
+	w = basep->ebox->requisition.width;
+	h = basep->ebox->requisition.height;
 
 	/* do a minimal 48 size*/
 	if(PANEL_WIDGET(basep->panel)->orient == PANEL_HORIZONTAL) {
@@ -180,6 +175,7 @@ drawer_widget_size_request(GtkWidget *widget,
 	requisition->height = h;
 }
 
+
 static void
 drawer_widget_get_pos(DrawerWidget *drawer, gint16 *x, gint16 *y,
 		      int width, int height)
@@ -187,50 +183,65 @@ drawer_widget_get_pos(DrawerWidget *drawer, gint16 *x, gint16 *y,
 	PanelWidget *panel = PANEL_WIDGET(BASEP_WIDGET(drawer)->panel);
 
 	if (panel->master_widget &&
-	    GTK_WIDGET_REALIZED (panel->master_widget)) {
+	    GTK_WIDGET_REALIZED (panel->master_widget) &&
+	    /*"allocated" data will be set on each allocation, until then,
+	      don't show the actual panel*/
+	    gtk_object_get_data(GTK_OBJECT(panel->master_widget),"allocated")) {
 		int bx, by, bw, bh;
 		int px, py, pw, ph;
 		GtkWidget *ppanel; /*parent panel*/
 
+		BasePWidget *basep;
+		
 		/*get the parent of the applet*/
 		ppanel = panel->master_widget->parent;
+		bx = panel->master_widget->allocation.x +
+			ppanel->allocation.x;
+		by = panel->master_widget->allocation.y +
+			ppanel->allocation.y;
 		/*go the the toplevel panel widget*/
-		while(ppanel->parent)
+		while(ppanel->parent) {
 			ppanel = ppanel->parent;
-		if (GTK_WIDGET_REALIZED (ppanel)) {
-			gdk_window_get_origin (panel->master_widget->window, &bx, &by);
-			if(GTK_WIDGET_NO_WINDOW(panel->master_widget)) {
-				bx+=panel->master_widget->allocation.x;
-				by+=panel->master_widget->allocation.y;
-			}
-			bw = panel->master_widget->allocation.width;
-			bh = panel->master_widget->allocation.height;
-			gdk_window_get_origin (ppanel->window, &px, &py);
-			gdk_window_get_size (ppanel->window, &pw, &ph);
-
-			switch(drawer->orient) {
-			case ORIENT_UP:
-				*x = bx+(bw-width)/2;
-				*y = py - height;
-				break;
-			case ORIENT_DOWN:
-				*x = bx+(bw-width)/2;
-				*y = py + ph;
-				break;
-			case ORIENT_LEFT:
-				*x = px - width;
-				*y = by+(bh-height)/2;
-				break;
-			case ORIENT_RIGHT:
-				*x = px + pw;
-				*y = by+(bh-height)/2;
-				break;
-			}
-			return;
+			bx += ppanel->allocation.x;
+			by += ppanel->allocation.y;
 		}
+		basep = BASEP_WIDGET(ppanel);
+		/*a hack as the above just doesn't work perfectly*/
+		if(GTK_WIDGET_VISIBLE(basep->hidebutton_n))
+			by -= basep->hidebutton_n->allocation.height;
+		if(GTK_WIDGET_VISIBLE(basep->hidebutton_w))
+			bx -= basep->hidebutton_w->allocation.width;
+
+		bw = panel->master_widget->allocation.width;
+		bh = panel->master_widget->allocation.height;
+		px = ppanel->allocation.x;
+		py = ppanel->allocation.y;
+		pw = ppanel->allocation.width;
+		ph = ppanel->allocation.height;
+
+		switch(drawer->orient) {
+		case ORIENT_UP:
+			*x = bx+(bw-width)/2;
+			*y = py - height;
+			break;
+		case ORIENT_DOWN:
+			*x = bx+(bw-width)/2;
+			*y = py + ph;
+			break;
+		case ORIENT_LEFT:
+			*x = px - width;
+			*y = by+(bh-height)/2;
+			break;
+		case ORIENT_RIGHT:
+			*x = px + pw;
+			*y = by+(bh-height)/2;
+			break;
+		}
+		return;
 	}
 	/*if we fail*/
-	*x = *y = -3000;
+	*x = -width-1;
+	*y = -height-1;
 }
 
 static void
@@ -241,15 +252,13 @@ drawer_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 	GtkAllocation challoc;
 	int w,h;
 
-	if(ignore_allocate)
-		return;
+	/*we actually want to ignore the size_reqeusts since they
+	  are sometimes a cube for the flicker prevention*/
+	gtk_widget_size_request (basep->ebox,
+				 &basep->ebox->requisition);
 
-	/*we actually want to ignore the size_reqeusts since they are sometimes
-	  a cube for the flicker prevention*/
-	gtk_widget_size_request (basep->table, &basep->table->requisition);
-
-	w = basep->table->requisition.width;
-	h = basep->table->requisition.height;
+	w = basep->ebox->requisition.width;
+	h = basep->ebox->requisition.height;
 
 	/* do a minimal 48 size*/
 	if(PANEL_WIDGET(basep->panel)->orient == PANEL_HORIZONTAL) {
@@ -265,29 +274,50 @@ drawer_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 			      &allocation->y,
 			      allocation->width,
 			      allocation->height);
-	
-	/*ugly optimisation*/
-	if(memcmp(allocation,&widget->allocation,sizeof(GtkAllocation))==0)
-		return;
 
+	basep->shown_alloc = *allocation;
+	
+	if(drawer->state != DRAWER_SHOWN ||
+	   drawer->temp_hidden) {
+		allocation->x = -allocation->width -1;
+		allocation->y = -allocation->height -1;
+	}
+	
 	widget->allocation = *allocation;
-	if (GTK_WIDGET_REALIZED (widget))
+	if (GTK_WIDGET_REALIZED (widget)) {
 		gdk_window_move_resize (widget->window,
-					allocation->x, 
+					allocation->x,
 					allocation->y,
-					allocation->width, 
+					allocation->width,
 					allocation->height);
+		gdk_window_set_hints (widget->window,
+				      allocation->x,
+				      allocation->y,
+				      0,0,0,0, GDK_HINT_POS);
+	} else if(widget->window) {
+		puts("NON_REALIZED_WINDOW");
+	}
+	
 
 	challoc.x = challoc.y = 0;
 	challoc.width = allocation->width;
 	challoc.height = allocation->height;
-	gtk_widget_size_allocate(basep->table,&challoc);
+	gtk_widget_size_allocate(basep->ebox,&challoc);
 }
 
 static void
 drawer_widget_set_hidebuttons(BasePWidget *basep)
 {
 	DrawerWidget *drawer = DRAWER_WIDGET(basep);
+
+	/*hidebuttons are disabled*/
+	if(!basep->hidebuttons_enabled) {
+		gtk_widget_hide(basep->hidebutton_n);
+		gtk_widget_hide(basep->hidebutton_e);
+		gtk_widget_hide(basep->hidebutton_w);
+		gtk_widget_hide(basep->hidebutton_s);
+		return;
+	}
 	
 	switch(drawer->orient) {
 	case ORIENT_UP:
@@ -303,180 +333,69 @@ drawer_widget_set_hidebuttons(BasePWidget *basep)
 		gtk_widget_show(basep->hidebutton_s);
 		break;
 	case ORIENT_LEFT:
-		gtk_widget_hide(basep->hidebutton_n);
-		gtk_widget_show(basep->hidebutton_e);
-		gtk_widget_hide(basep->hidebutton_w);
-		gtk_widget_hide(basep->hidebutton_s);
-		break;
-	case ORIENT_RIGHT:
 		gtk_widget_hide(basep->hidebutton_n);
 		gtk_widget_hide(basep->hidebutton_e);
 		gtk_widget_show(basep->hidebutton_w);
 		gtk_widget_hide(basep->hidebutton_s);
 		break;
+	case ORIENT_RIGHT:
+		gtk_widget_hide(basep->hidebutton_n);
+		gtk_widget_show(basep->hidebutton_e);
+		gtk_widget_hide(basep->hidebutton_w);
+		gtk_widget_hide(basep->hidebutton_s);
+		break;
 	}
 }
 
-static int
-move_step(int src, int dest, int pos, int step)
-{
-	int range = abs(src-dest);
-	int diff = abs(range-abs(pos-src));
-	int percentage = (diff*100)/range;
-
-	if(percentage>50)
-		percentage = 100-percentage;
-	
-	return ((step>>1)*log((percentage/10.0)+1))+1;
-}
-
-static void
-move_horiz_d(DrawerWidget *drawer, int x, int y, int w, int h,
-	    int src_x, int dest_x, int step, int hide)
-{
-	int orig_x;
-	int orig_w;
-	GtkWidget *wid = GTK_WIDGET(drawer);
-
-	if(!hide)
-		w = 0;
-
-	orig_x = x;
-	orig_w = w;
-
-	if (!pw_disable_animations && step != 0) {
-		if (src_x < dest_x) {
-			for( x = src_x; x < dest_x;
-			     x+= move_step(src_x,dest_x,x,step)) {
-				if(hide) {
-					move_resize_window(wid,
-							   x, y, w, h);
-					w-=move_step(src_x,dest_x,x,step);
-				} else {
-					move_resize_window(wid,
-							   orig_x, y, w, h);
-					w+=move_step(src_x,dest_x,x,step);
-				}
-			}
-		} else {
-			for (x = src_x; x > dest_x;
-			     x-= move_step(src_x,dest_x,x,step)) {
-				if(hide) {
-					move_resize_window(wid,
-							   orig_x, y, w, h);
-					w-=move_step(src_x,dest_x,x,step);
-				} else {
-					move_resize_window(wid,
-							   x, y, w, h);
-					w+=move_step(src_x,dest_x,x,step);
-				}
-			}
-		}
-	}
-	
-	if(hide)
-		w = orig_w - abs(src_x-dest_x);
-	else
-		w = orig_w + abs(src_x-dest_x);
-
-	move_resize_window(wid, dest_x, y,w,h);
-}
-
-static void
-move_vert_d(DrawerWidget *drawer, int x, int y, int w, int h,
-	    int src_y, int dest_y, int step, int hide)
-{
-	int orig_y;
-	int orig_h;
-	GtkWidget *wid = GTK_WIDGET(drawer);
-
-	if(!hide)
-		h = 0;
-
-	orig_y = y;
-	orig_h = h;
-
-	if (!pw_disable_animations && step != 0) {
-		if (src_y < dest_y) {
-			for( y = src_y; y < dest_y;
-			     y+= move_step(src_y,dest_y,y,step)) {
-				if(hide) {
-					move_resize_window(wid,
-							   x, y, w, h);
-					h-=move_step(src_y,dest_y,y,step);
-				} else {
-					move_resize_window(wid,
-							   x, orig_y, w, h);
-					h+=move_step(src_y,dest_y,y,step);
-				}
-			}
-		} else {
-			for (y = src_y; y > dest_y;
-			     y-= move_step(src_y,dest_y,y,step)) {
-				if(hide) {
-					move_resize_window(wid,
-							   x, orig_y, w, h);
-					h-=move_step(src_y,dest_y,y,step);
-				} else {
-					move_resize_window(wid,
-							   x, y, w, h);
-					h+=move_step(src_y,dest_y,y,step);
-				}
-			}
-		}
-	}
-	
-	if(hide)
-		h = orig_h - abs(src_y-dest_y);
-	else
-		h = orig_h + abs(src_y-dest_y);
-
-	move_resize_window(wid, x, dest_y, w,h);
-}
-
 void
 drawer_widget_open_drawer(DrawerWidget *drawer)
 {
+	static const char *supinfo[] = {"panel", "collapse", NULL};
 	gint16 x=0,y=0;
 	int width, height;
 
 	if((drawer->state == DRAWER_SHOWN) ||
 	   (drawer->state == DRAWER_MOVING))
 		return;
-	
+
 	if(!GTK_WIDGET(drawer)->window) {
 		gtk_widget_queue_resize(GTK_WIDGET(drawer));
 		drawer->state = DRAWER_SHOWN;
 		return;
 	}
 
+	gnome_triggers_vdo("", NULL, supinfo);
+
 	width   = GTK_WIDGET(drawer)->allocation.width;
 	height  = GTK_WIDGET(drawer)->allocation.height;
 	drawer_widget_get_pos(drawer,&x,&y,width,height);
+	GTK_WIDGET(drawer)->allocation.x = x;
+	GTK_WIDGET(drawer)->allocation.y = y;
 
 	drawer->state = DRAWER_MOVING;
 
-	gdk_window_move(GTK_WIDGET(drawer)->window, -3000,-3000);
-	ignore_allocate = TRUE;
-	gtk_widget_show_now(GTK_WIDGET(drawer));
-	ignore_allocate = FALSE;
 	switch(drawer->orient) {
 	case ORIENT_UP:
-		move_vert_d(drawer,x,y,width,height, y+height, y,
-			    pw_drawer_step,FALSE);
+		BASEP_WIDGET(drawer)->shown_alloc.y += 
+			BASEP_WIDGET(drawer)->shown_alloc.height;
+		basep_widget_do_showing(BASEP_WIDGET(drawer), ORIENT_DOWN,
+					0,pw_drawer_step);
 		break;
 	case ORIENT_DOWN:
-		move_vert_d(drawer,x,y,width,height, y-height, y,
-			    pw_drawer_step,FALSE);
+		basep_widget_do_showing(BASEP_WIDGET(drawer), ORIENT_UP,
+					0,pw_drawer_step);
 		break;
 	case ORIENT_LEFT:
-		move_horiz_d(drawer,x,y,width,height, x+width, x,
-			     pw_drawer_step,FALSE);
+		BASEP_WIDGET(drawer)->shown_alloc.x += 
+			BASEP_WIDGET(drawer)->shown_alloc.width;
+		basep_widget_do_showing(BASEP_WIDGET(drawer), ORIENT_RIGHT,
+					0,pw_drawer_step);
 		break;
 	case ORIENT_RIGHT:
-		move_horiz_d(drawer,x,y,width,height, x-width, x,
-			     pw_drawer_step,FALSE);
+		basep_widget_do_showing(BASEP_WIDGET(drawer), ORIENT_LEFT,
+					0,pw_drawer_step);
 		break;
+	default: break;
 	}
 
 	drawer->state = DRAWER_SHOWN;
@@ -491,6 +410,7 @@ drawer_widget_open_drawer(DrawerWidget *drawer)
 void
 drawer_widget_close_drawer(DrawerWidget *drawer)
 {
+	static const char *supinfo[] = {"panel", "collapse", NULL};
 	gint16 x=0,y=0;
 	int width, height;
 
@@ -504,6 +424,8 @@ drawer_widget_close_drawer(DrawerWidget *drawer)
 		return;
 	}
 
+	gnome_triggers_vdo("", NULL, supinfo);
+
 	gtk_signal_emit(GTK_OBJECT(drawer),
 			drawer_widget_signals[STATE_CHANGE_SIGNAL],
 			DRAWER_HIDDEN);
@@ -511,32 +433,31 @@ drawer_widget_close_drawer(DrawerWidget *drawer)
 	width   = GTK_WIDGET(drawer)->allocation.width;
 	height  = GTK_WIDGET(drawer)->allocation.height;
 	drawer_widget_get_pos(drawer,&x,&y,width,height);
+	GTK_WIDGET(drawer)->allocation.x = x;
+	GTK_WIDGET(drawer)->allocation.y = y;
 
 	drawer->state = DRAWER_MOVING;
-
-	if(!pw_disable_animations) {
-		switch(drawer->orient) {
-		case ORIENT_UP:
-			move_vert_d(drawer,x,y,width,height, y, y+height,
-				    pw_drawer_step, TRUE);
-			break;
-		case ORIENT_DOWN:
-			move_vert_d(drawer,x,y,width,height, y, y-height,
-				    pw_drawer_step, TRUE);
-			break;
-		case ORIENT_LEFT:
-			move_horiz_d(drawer,x,y,width,height, x, x+width,
-				     pw_drawer_step, TRUE);
-			break;
-		case ORIENT_RIGHT:
-			move_horiz_d(drawer,x,y,width,height, x, x-width,
-				     pw_drawer_step, TRUE);
-			break;
-		}
+	
+	switch(drawer->orient) {
+	case ORIENT_UP:
+		basep_widget_do_hiding(BASEP_WIDGET(drawer), ORIENT_DOWN,
+				       0,pw_drawer_step);
+		break;
+	case ORIENT_DOWN:
+		basep_widget_do_hiding(BASEP_WIDGET(drawer), ORIENT_UP,
+				       0,pw_drawer_step);
+		break;
+	case ORIENT_LEFT:
+		basep_widget_do_hiding(BASEP_WIDGET(drawer), ORIENT_RIGHT,
+				       0,pw_drawer_step);
+		break;
+	case ORIENT_RIGHT:
+		basep_widget_do_hiding(BASEP_WIDGET(drawer), ORIENT_LEFT,
+				       0,pw_drawer_step);
+		break;
+	default: break;
 	}
 
-	gtk_widget_hide(GTK_WIDGET(drawer));
-
 	drawer->state = DRAWER_HIDDEN;
 }
 
@@ -556,11 +477,11 @@ drawer_handle_click(GtkWidget *widget, gpointer data)
 		SNAPPED_WIDGET(panelw)->drawers_open--;
 }
 
-
 static void
 drawer_widget_init (DrawerWidget *drawer)
 {
 	drawer->state = DRAWER_SHOWN;
+	drawer->temp_hidden = FALSE;
 }
 
 GtkWidget*
@@ -701,6 +622,7 @@ drawer_widget_change_orient(DrawerWidget *drawer,
 void
 drawer_widget_restore_state(DrawerWidget *drawer)
 {
+	drawer->temp_hidden = FALSE;
 	gtk_widget_queue_resize(GTK_WIDGET(drawer));
 	gtk_widget_show(GTK_WIDGET(drawer));
 }
