@@ -235,23 +235,13 @@ create_drawer_applet(GtkWidget * drawer_panel, char *tooltip, char *pixmap,
 
 	if(!pixmap || !*pixmap) {
 		drawer->pixmap = gnome_pixmap_file ("panel-drawer.png");
-		drawer->button = button_widget_new_from_file (drawer->pixmap,
-							      DRAWER_TILE,
-							      TRUE,orient);
 	} else {
-		drawer->button = button_widget_new_from_file(pixmap,
-							     DRAWER_TILE,
-							     TRUE,orient);
-		if(drawer->button)
-			drawer->pixmap = g_strdup(pixmap);
-		else {
-			drawer->pixmap = gnome_pixmap_file ("panel-drawer.png");
-			drawer->button =
-				button_widget_new_from_file (drawer->pixmap,
-							     DRAWER_TILE,
-							     TRUE,orient);
-		}
+		drawer->pixmap = g_strdup(pixmap);
 	}
+	drawer->button = button_widget_new_from_file (drawer->pixmap,
+						      DRAWER_TILE,
+						      TRUE,orient,
+						      _("Drawer"));
 
 	gtk_widget_show(drawer->button);
 
@@ -275,11 +265,11 @@ static Drawer *
 create_empty_drawer_applet(char *tooltip, char *pixmap,
 			   PanelOrientType orient)
 {
-	return create_drawer_applet(drawer_widget_new(orient,
-						      DRAWER_SHOWN,
-						      PANEL_BACK_NONE, NULL,
-						      TRUE, NULL, TRUE, TRUE),
-				    tooltip,pixmap,orient);
+	DrawerWidget *dw = drawer_widget_new(orient,
+					     DRAWER_SHOWN,
+					     PANEL_BACK_NONE, NULL,
+					     TRUE, NULL, TRUE, TRUE);
+	return create_drawer_applet(dw, tooltip,pixmap,orient);
 }
 
 void
@@ -299,16 +289,17 @@ set_drawer_applet_orient(Drawer *drawer, PanelOrientType orient)
 }
 
 static void
-drawer_realize_cb(GtkWidget *button, Drawer *drawer)
+drawer_setup(Drawer *drawer)
 {
 	gtk_widget_queue_resize(drawer->drawer);
-	if(DRAWER_WIDGET(drawer->drawer)->state == DRAWER_SHOWN)
-		gtk_widget_show(drawer->drawer);
-	else {
-		if(!GTK_WIDGET_REALIZED(drawer->drawer))
-			gtk_widget_realize(drawer->drawer);
-		gtk_widget_hide(drawer->drawer);
+	if(DRAWER_WIDGET(drawer->drawer)->state != DRAWER_SHOWN) {
+		gtk_widget_size_request(drawer->drawer,
+					&drawer->drawer->requisition);
+		gtk_widget_set_uposition(drawer->drawer,
+					 -drawer->drawer->requisition.width - 1,
+					 -drawer->drawer->requisition.height - 1);
 	}
+	gtk_widget_show(drawer->drawer);
 }
 
 static void
@@ -320,9 +311,6 @@ drawer_move_foreach(GtkWidget *w, gpointer user_data)
 		Drawer *drawer = info->data;
 		BasePWidget *basep = BASEP_WIDGET(drawer->drawer);
 		gtk_widget_queue_resize(drawer->drawer);
-		gtk_container_foreach(GTK_CONTAINER(basep->panel),
-				      drawer_move_foreach,
-				      NULL);
 	}
 }
 
@@ -332,6 +320,7 @@ button_size_alloc(GtkWidget *widget, GtkAllocation *alloc, Drawer *drawer)
 	if(!GTK_WIDGET_REALIZED(widget))
 		return;
 	drawer_move_foreach(widget,NULL);
+	gtk_object_set_data(GTK_OBJECT(widget),"allocated",GINT_TO_POINTER(1));
 }
 
 void
@@ -362,8 +351,6 @@ load_drawer_applet(int mypanel, char *pixmap, char *tooltip,
 	if(!drawer)
 		return;
 
-	g_return_if_fail(drawer != NULL);
-
 	register_toy(drawer->button,drawer, panel, pos, APPLET_DRAWER);
 
 	gtk_signal_connect_after(GTK_OBJECT(drawer->button),
@@ -382,27 +369,7 @@ load_drawer_applet(int mypanel, char *pixmap, char *tooltip,
 
 	gtk_tooltips_set_tip (panel_tooltips,drawer->button,
 			      drawer->tooltip,NULL);
-	if(GTK_WIDGET_REALIZED(drawer->button)) {
-		gtk_widget_queue_resize(drawer->drawer);
-		if(DRAWER_WIDGET(drawer->drawer)->state == DRAWER_SHOWN)
-			gtk_widget_show(drawer->drawer);
-		else {
-			/*hmm ... weird but it works*/
-			gtk_widget_set_uposition(drawer->drawer,
-						 -100,-100);
-			gtk_widget_show(drawer->drawer);
-			/*gtk_widget_realize(drawer->drawer);*/
-			gtk_widget_hide(drawer->drawer);
-		}
-	} else
-		gtk_signal_connect_after(GTK_OBJECT(drawer->button),
-					 "realize",
-					 GTK_SIGNAL_FUNC(drawer_realize_cb),
-					 drawer);
-	gtk_signal_connect_after(GTK_OBJECT(drawer->drawer),
-				 "realize",
-				 GTK_SIGNAL_FUNC(drawer_realize_cb),
-				 drawer);
+	drawer_setup(drawer);
 
 	g_return_if_fail(applets_last!=NULL);
 
