@@ -352,14 +352,17 @@ state_restore_foreach(GtkWidget *w, gpointer data)
 	if(info->type == APPLET_DRAWER) {
 		Drawer *drawer = info->data;
 		DrawerWidget *dw = DRAWER_WIDGET(drawer->drawer);
+		BasePWidget *basep = BASEP_WIDGET(drawer->drawer);
 		if(dw->state == DRAWER_SHOWN) {
 			drawer_widget_restore_state(dw);
-			gtk_container_foreach(GTK_CONTAINER(BASEP_WIDGET(dw)->panel),
+			gtk_container_foreach(GTK_CONTAINER(basep->panel),
 					      state_restore_foreach,
 					      NULL);
 		} else { /*it's hidden*/
-			gtk_widget_hide(drawer->drawer);
-			gtk_container_foreach(GTK_CONTAINER(BASEP_WIDGET(dw)->panel),
+			dw->temp_hidden = FALSE;
+			gtk_widget_size_allocate(drawer->drawer,
+						 &drawer->drawer->allocation);
+			gtk_container_foreach(GTK_CONTAINER(basep->panel),
 					      state_hide_foreach,
 					      NULL);
 		}
@@ -374,7 +377,10 @@ state_hide_foreach(GtkWidget *w, gpointer data)
 	if(info->type == APPLET_DRAWER) {
 		Drawer *drawer = info->data;
 		BasePWidget *basep = BASEP_WIDGET(drawer->drawer);
-		gtk_widget_hide(drawer->drawer);
+		DrawerWidget *dw = DRAWER_WIDGET(drawer->drawer);
+		dw->temp_hidden = TRUE;
+		gtk_widget_size_allocate(drawer->drawer,
+					 &drawer->drawer->allocation);
 		gtk_container_foreach(GTK_CONTAINER(basep->panel),
 				      state_hide_foreach,
 				      NULL);
@@ -439,15 +445,24 @@ drawer_state_change(GtkWidget *widget,
 	return TRUE;
 }
 
-static int
-panel_size_allocate(GtkWidget *widget, GtkAllocation *alloc, gpointer data)
+static void
+queue_resize_foreach(GtkWidget *w, gpointer data)
 {
-	if(IS_DRAWER_WIDGET(widget)) {
-		if(DRAWER_WIDGET(widget)->state == DRAWER_SHOWN)
-			gtk_widget_queue_resize(widget);
-		panels_to_sync = TRUE;
+	AppletInfo *info = gtk_object_get_data(GTK_OBJECT(w), "applet_info");
+
+	if(info->type == APPLET_DRAWER) {
+		Drawer *drawer = info->data;
+		BasePWidget *basep = BASEP_WIDGET(drawer->drawer);
+		DrawerWidget *dw = DRAWER_WIDGET(drawer->drawer);
+		
+		if(dw->state == DRAWER_SHOWN &&
+		   !dw->temp_hidden) {
+			gtk_widget_queue_resize(drawer->drawer);
+			/*gtk_container_foreach(GTK_CONTAINER(basep->panel),
+					      queue_resize_foreach,
+					      NULL);*/
+		}
 	}
-	return FALSE;
 }
 
 /*the following is slightly ugly .... but it works, I need to send the
@@ -566,6 +581,14 @@ snapped_panel_move(SnappedWidget *snapped, double x, double y)
 	    y >= miny &&
 	    y <= maxy)
  	        return;
+	
+	/*if in the inner 1/3rd, don't change to avoid fast flickery
+	  movement*/
+	if ( x>(gdk_screen_width()/3) &&
+	     x<(2*gdk_screen_width()/3) &&
+	     y>(gdk_screen_height()/3) &&
+	     y<(2*gdk_screen_height()/3))
+		return;
 
 	if ((x) * gdk_screen_height() > y * gdk_screen_width() ) {
 		if(gdk_screen_height() * (gdk_screen_width()-(x)) >
@@ -602,6 +625,14 @@ corner_panel_move(CornerWidget *corner, double x, double y)
 	    y <= maxy)
  	        return;
 
+	/*if in the inner 1/3rd, don't change to avoid fast flickery
+	  movement*/
+	if ( x>(gdk_screen_width()/3) &&
+	     x<(2*gdk_screen_width()/3) &&
+	     y>(gdk_screen_height()/3) &&
+	     y<(2*gdk_screen_height()/3))
+		return;
+
 	if ((x) * gdk_screen_height() > y * gdk_screen_width() ) {
 		if(gdk_screen_height() * (gdk_screen_width()-(x)) >
 		   y * gdk_screen_width() ) {
@@ -887,7 +918,7 @@ panel_widget_dnd_drop_internal (GtkWidget *widget,
 			  char *p;
 
 			  p = g_strdup_printf("Open URL: %s",
-					      ltmp->data);
+					      (char *)ltmp->data);
 			  load_launcher_applet_from_info(ltmp->data,
 							 p,exec,2,
 							 "netscape.png",
@@ -1116,8 +1147,6 @@ panel_setup(GtkWidget *panelw)
 			      gtk_widget_get_events(panelw) |
 			      PANEL_EVENT_MASK);
 
-	gtk_signal_connect(GTK_OBJECT(panelw), "size_allocate",
-			   GTK_SIGNAL_FUNC(panel_size_allocate), NULL);
 	gtk_signal_connect(GTK_OBJECT(panelw), "destroy",
 			   GTK_SIGNAL_FUNC(panel_destroy),NULL);
 
