@@ -63,6 +63,7 @@ config_apply (GtkWidget *widget, int page, gpointer data)
 	for(i=0;i<LAST_TILE;i++) {
 		global_config.tile_up[i] =
 			gnome_icon_entry_get_filename(GNOME_ICON_ENTRY(entry_up[i]));
+		printf("TILE_UP[%d]=%s\n",i,global_config.tile_up[i]);
 		global_config.tile_down[i] =
 			gnome_icon_entry_get_filename(GNOME_ICON_ENTRY(entry_down[i]));
 	}
@@ -555,8 +556,11 @@ panel_config_global(void)
 	int i;
 	
 	/* return if the window is already up. */
-	if (config_window)
+	if (config_window) {
+		gdk_window_raise(config_window->window);
+		gtk_widget_show(config_window);
 		return;
+	}
 
 	memcpy(&temp_config,&global_config,sizeof(GlobalConfig));
 
